SickChill would not be possible without the at least tens of thousands of contributor coding and debugging hours spent making this project what it is today.
We want to give a special thanks to everyone who contributed in the past or who will contribute in the future.
As my professor described it "People you will never know working and building great things just to give away to people they will never know"
Some people in this list might deserve special recognition, (MidgetSpy, Mr_Orange, etc) but for now it is simply an alphabetical list of contributors.

This is in no way a complete list of contributors. This list was generated from file-level licenses when converting to a project-wide license file.
A more complete list can be seen by checking the commit log of SickBeard, SickRAGE, SickChill, and other forks of SickBeard.
If you feel you should be included in this file, please feel free to make a PR and list your contribution, or ping @miigotu
You may also request to have your specific contribution designated here in this file.

- [Aaron Bieber](mailto:deftly@gmail.com)
- [adaur](mailto:adaur.underground@gmail.com)
- [Antoine Bertin](mailto:diaoulael@gmail.com)
- [Chris Burton](mailto:cyberhiker@gmail.com)
- [Clinton Collins](mailto:clinton.collins@gmail.com)
- [DarkSupremo](mailto:uilton.dev@gmail.com)
- [Derek Battams](mailto:derek@battams.ca)
- [Dermot Buckley](mailto:dermot@buckley.ie)
- [Dieter Blomme](mailto:dieterblomme@gmail.com)
- [Dustyn Gibson](mailto:miigotu@gmail.com)
- [ellmout](mailto:ellmout@ellmout.net)
- [Gonçalo M.](mailto:supergonkas@gmail.com)
- [Gordon Turner](mailto:gordonturner@gordonturner.ca)
- [Guillaume Serre](mailto:guillaume.serre@gmail.com)
- [Joao Santos](mailto:jmigueltsantos@riseup.net)
- [Jonathon Saine](mailto:thezoggy@gmail.com)
- [Jordon Smith](mailto:smith@jordon.me.uk)
- [Ludovic Reenaers](mailto:ludovic.reenaers@gmail.com)
- [Marvin Pinto](mailto:me@marvinp.ca)
- [medariox](mailto:dariox@gmx.com)
- [Mhynlo](mailto:mhynlo@mhynlo.io)
- [moparisthebest](mailto:admin@moparisthebest.com)
- [Mr_Orange](mailto:mr_orange@hotmail.it)
- [Nic Wolfe](mailto:nic@wolfeden.ca)
- [Nyaran](mailto:nyayukko@gmail.com)
- [Pedro Jose Pereira Vieito (@pvieito)](mailto:pvieito@gmail.com)
- [PHD](mailto:phd59fr@gmail.com)
- [Rafael Silva](mailto:rpluto@gmail.com)
- [Sebastien Erard](mailto:sebastien_erard@hotmail.com)
- [Tyler Fenby](mailto:tylerfenby@gmail.com)
